import axios from 'axios'
import { Message } from 'element-ui'

export const httpx = axios.create({
  timeout: 1000 * 5,
  // withCredentials: true,
  headers: {
    'Content-Type': 'application/json; charset=utf-8'
  }
})

httpx.interceptors.response.use(
  (response) => {
    if (response.data.code >= 0) {
      response.statusText = response.data.msg;
      response.data = response.data.data;
      return response;
    } else {
      Message({
        message: response.data.msg,
        type: 'error',
        duration: 1500,
        customClass: 'element-error-message-zindex'
      })
      return Promise.reject()
    }
  }, (error) => {
    switch (error.response.status) {
      case 400:
        Message({
          message: error.response.data,
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
                break
      case 401:
        // clearLoginInfo()
        // router.push({ name: 'login' })
        break
      case 405:
        Message({
          message: 'http请求方式有误',
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
        break
      case 500:
        Message({
          message: '服务器出了点小差，请稍后再试',
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
        break
      case 501:
        Message({
          message: '服务器不支持当前请求所需要的某个功能',
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
        break
    }
    return Promise.reject(error)
  }
)

export default httpx
export { AxiosPromise, AxiosResponse } from "axios"